# -*- coding: utf-8 -*-

from setuptools import setup, find_packages


# with open('README.rst') as f:
#     readme = f.read()
#
# with open('LICENSE') as f:
#     license = f.read()

# setup(
#     name='sample',
#     version='0.1.0',
#     description='Sample package for Python-Guide.org',
#     long_description=readme,
#     author='Kenneth Reitz',
#     author_email='me@kennethreitz.com',
#     url='https://github.com/kennethreitz/samplemod',
#     license=license,
#     packages=find_packages(exclude=('tests', 'docs'))
# )
setup(
    name='bot_ai',
    version='0.0.1',
    description='Artificial Intelligence',
    author='Fernando Oliveira',
    author_email='fernando.oliveira@virtus.ufcg.edu.br',
    url='https://github.com/mateuscomp/bot_ai',
    packages=find_packages(exclude=('tests', 'docs'))
)